text stringlengths 2 99.9k | meta dict |
|---|---|
#!/usr/bin/env python3
# ##### BEGIN GPL LICENSE BLOCK #####
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# ... | {
"pile_set_name": "Github"
} |
//
// QQApi.h
// QQApi
//
// Created by Tencent on 5/1/12.
// Copyright (c) 2012 Tencent. All rights reserved.
//
/** @file */
#import <Foundation/Foundation.h>
@class QQApiObject;
@class QQApiMessage;
@class QQApiAdItem;
typedef enum
{
EQQAPISENDSUCESS = 0,
EQQAPIQQNOTINSTALLED = 1,
EQQAPIQQNOTSUPP... | {
"pile_set_name": "Github"
} |
from gevent import monkey
_PATCHED = False
if not _PATCHED:
monkey.patch_all(thread=False, select=False)
_PATCHED = True
from ._version import __version__ # noqa: F401, E402
from .lazy import LazyGraph, LazyNode, node # noqa: F401, E402
from .functional import pipeline, stop # noqa: F401, E402
from .stre... | {
"pile_set_name": "Github"
} |
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" con... | {
"pile_set_name": "Github"
} |
version: 1
n_points: 4
{
468.115 356.685
468.115 858.122
941.695 858.122
941.695 356.685
}
| {
"pile_set_name": "Github"
} |
// Copyright 2005, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
// notice, this list of conditions ... | {
"pile_set_name": "Github"
} |
/***
* Copyright (C) Microsoft. All rights reserved.
* Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
*
* =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
*
* HTTP Library: Compression and decompression inter... | {
"pile_set_name": "Github"
} |
#ifndef MATH_HPP_
#define MATH_HPP_
#include <math.h>
#include <stdint.h>
template <class T1, class T2>
T1 ceil_aligned(T1 value, T2 alignment) {
return value + alignment - (((value + alignment - 1) % alignment) + 1);
}
template <class T1, class T2>
T1 ceil_divide(T1 dividend, T2 alignment) {
return (dividen... | {
"pile_set_name": "Github"
} |
/*
* Copyright (c) 2018-present, 美团点评
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publi... | {
"pile_set_name": "Github"
} |
{
"uri": "\/2010-04-01\/Accounts\/ACXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX\/AvailablePhoneNumbers\/GB\/Local.json?VoiceEnabled=true&SmsEnabled=true",
"available_phone_numbers": [
{
"friendly_name": "+442033224780",
"phone_number": "+442033224780",
"iso_country": "GB",
"capabilities":{
... | {
"pile_set_name": "Github"
} |
Sym_type: module
Sym_name: top
Sym_lineno: 0
Sym_nested: False
Sym_haschildren: False
-- Identifiers --
name: True
is_referenced: True
is_imported: False
is_parameter: False
is_global: True
is_declared_global: False
is_local: False
is_free: False
is_assigned: False
is_namespace: False
namespaces: [
... | {
"pile_set_name": "Github"
} |
/* Copyright (c) 2020, NVIDIA CORPORATION. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* * Redistributions of source code must retain the above copyright
* notice, this list of condi... | {
"pile_set_name": "Github"
} |
.include "macros.inc"
start
test_name XNOR_1
mvi r1, 0
mvi r2, 0
xnor r3, r1, r2
check_r3 0xffffffff
test_name XNOR_2
mvi r1, 0
mvi r2, 1
xnor r3, r1, r2
check_r3 0xfffffffe
test_name XNOR_3
mvi r1, 1
mvi r2, 1
xnor r3, r1, r2
check_r3 0xffffffff
test_name XNOR_4
mvi r1, 1
mvi r2, 0
xnor r3, r1, r2
check_r3 0xffff... | {
"pile_set_name": "Github"
} |
<?php
namespace Faker\Test\Provider\fr_CH;
use Faker\Generator;
use Faker\Provider\fr_CH\Address;
use Faker\Provider\fr_CH\Person;
use PHPUnit\Framework\TestCase;
class AddressTest extends TestCase
{
/**
* @var Faker\Generator
*/
private $faker;
public function setUp()
{
$faker = ... | {
"pile_set_name": "Github"
} |
{
"$schema": "http://json-schema.org/draft-04/schema#",
"title": "getAccountInfo",
"type": "object",
"properties": {
"sequence": {
"$ref": "sequence",
"description": "The next (smallest unused) sequence number for this account."
},
"xrpBalance": {
"$ref": "value",
"descriptio... | {
"pile_set_name": "Github"
} |
Literals
-----
<?php
<<<'STR'
STR;
<<<STR
STR;
<<<'STR'
A
B
STR;
<<<STR
A
B
STR;
<<<'STR'
a\nb$c
STR;
<<<STR
a\\nb\$c
STR;
<<<STR
a$b
{$c->d}
STR;
call(
<<<STR
A
STR
, <<<STR
B
STR
);
function test() {
<<<STR
Foo
STR;
<<<STR
Bar
STR;
}
-----
<<<'STR'
STR;
<<<STR
STR;
<<<'STR'
A
B
STR;
<<<STR
A... | {
"pile_set_name": "Github"
} |
Telegram
| {
"pile_set_name": "Github"
} |
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
* This file is part of the LibreOffice project.
*
* This Source Code Form is subject to the terms of the Mozilla Public
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at http://mozil... | {
"pile_set_name": "Github"
} |
var baseClamp = require('./_baseClamp'),
shuffleSelf = require('./_shuffleSelf'),
values = require('./values');
/**
* The base implementation of `_.sampleSize` without param guards.
*
* @private
* @param {Array|Object} collection The collection to sample.
* @param {number} n The number of elements to samp... | {
"pile_set_name": "Github"
} |
source 'https://rubygems.org'
# Specify your gem's dependencies in ruby-unf_ext.gemspec
gemspec
| {
"pile_set_name": "Github"
} |
/*
* Programming interface for wlap_api.
* Copyright (C) 2011 HD Wireless AB
*
* You should have received a copy of the license along with this library.
*/
/*! \file wlap_api.h *************************************************************
*
* \brief WiFi AP API
*
* This file provides the wlap_api interface... | {
"pile_set_name": "Github"
} |
{
"name": "ABI38_0_0EXVideoThumbnails",
"version": "4.2.1",
"summary": "ExpoVideoThumbnails standalone module",
"description": "ExpoVideoThumbnails standalone module",
"license": "MIT",
"authors": "650 Industries, Inc.",
"homepage": "https://github.com/expo/expo/tree/master/packages/expo-video-thumbnails"... | {
"pile_set_name": "Github"
} |
// @remove-file-on-eject
/**
* Copyright (c) 2015-present, Facebook, Inc.
*
* This source code is licensed under the MIT license found in the
* LICENSE file in the root directory of this source tree.
*/
'use strict';
// Makes the script crash on unhandled rejections instead of silently
// ignoring them. In the fu... | {
"pile_set_name": "Github"
} |
// Copyright 2020 Anapaya Systems
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to... | {
"pile_set_name": "Github"
} |
// Copyright 2019, The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE.md file.
package flags
// Deterministic controls whether the output of Diff should be deterministic.
// This is only used for testing.
var Deterministic bool
| {
"pile_set_name": "Github"
} |
is_synthetic=false
feature=4
mu=1.000000
visualization=true
sequential=1
normal_radius=0.050000
normalize_points=false
estimate_normal=false
feature_radius=0.070000
max_iteration=32
max_correspondence_distance=0.012500
resample_leaf=0.000000
correspondence_dual_K=1
multiway_optimize=false
matching_ratiotest=false
match... | {
"pile_set_name": "Github"
} |
/*
* Copyright 2000-2014 JetBrains s.r.o.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agre... | {
"pile_set_name": "Github"
} |
. CONFIG
# Use this to change which GPU you use.
ID=1
# Batch size
BS=64
# Generator size
NGF=128
# Discriminator size
NDF=128
display_id=824${ID} \
num_holdout=1 \
port=8000 \
display=1 \
gpu=${ID} \
dataset='cub_keypoint_only' \
name="cub_nh1_kptxt2kp_bs${BS}_ngf${NGF}_ndf${NDF}" \
img_dir=${CUB_IMG_DIR} \
data_ro... | {
"pile_set_name": "Github"
} |
/*
* DateJS Culture String File
* Country Code: tt-RU
* Name: Tatar (Russia)
* Format: "key" : "value"
* Key is the en-US term, Value is the Key in the current language.
*/
Date.CultureStrings = Date.CultureStrings || {};
Date.CultureStrings["tt-RU"] = {
"name": "tt-RU",
"englishName": "Tatar (Ru... | {
"pile_set_name": "Github"
} |
// Code generated by linux/mkall.go generatePtracePair(mips, mips64). DO NOT EDIT.
// +build linux
// +build mips mips64
package unix
import "unsafe"
// PtraceRegsMips is the registers used by mips binaries.
type PtraceRegsMips struct {
Regs [32]uint64
Lo uint64
Hi uint64
Epc uint64
Badvad... | {
"pile_set_name": "Github"
} |
#pragma once
#include "RGBDSensor.h"
#include "CUDAImageUtil.h"
#include "CUDAImageCalibrator.h"
#include "GlobalBundlingState.h"
#include "TimingLog.h"
#include <cuda_runtime.h>
class CUDAImageManager {
public:
class ManagedRGBDInputFrame {
public:
friend class CUDAImageManager;
static void g... | {
"pile_set_name": "Github"
} |
[
{
"Id": "3e399241",
"IdLineage": [
"sfdsfdsfs",
"sdfdsfdsf"
],
"Individuals": [
{
"Id": "1232112",
"IdLineage": [
"fdsfsd1"
],
"Events": [
{
"RecordId": "2132121321",
"RecordType": "SALE",
"E... | {
"pile_set_name": "Github"
} |
//
// Generated by class-dump 3.5 (64 bit) (Debug version compiled Oct 15 2018 10:31:50).
//
// class-dump is Copyright (C) 1997-1998, 2000-2001, 2004-2015 by Steve Nygard.
//
#import <objc/NSObject.h>
@class NSArray, NSMutableDictionary, NSSet, NSString;
@interface TMRulesEngineBOM : NSObject
{
unsigned... | {
"pile_set_name": "Github"
} |
## Introduction
Get random value from a random generator, built-in methods of phaser.
- Author: Richard Davey
## Usage
### Random data generator
- Pre-defined random data generator
```javascript
var rnd = Phaser.Math.RND;
```
- New random generator
```javascript
var rnd = new Phaser.Math.Random... | {
"pile_set_name": "Github"
} |
<?php
/**
* Class Minify_CSS_UriRewriter
* @package Minify
*/
/**
* Rewrite file-relative URIs as root-relative in CSS files
*
* @package Minify
* @author Stephen Clay <steve@mrclay.org>
*/
class Minify_CSS_UriRewriter {
/**
* rewrite() and rewriteRelative() append debugging information here
... | {
"pile_set_name": "Github"
} |
# Copyright 2010 The Kyua Authors.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and th... | {
"pile_set_name": "Github"
} |
CONFIG_PPC=y
CONFIG_MPC85xx=y
CONFIG_TARGET_C29XPCIE=y
CONFIG_FIT=y
CONFIG_FIT_VERBOSE=y
CONFIG_OF_BOARD_SETUP=y
CONFIG_OF_STDOUT_VIA_ALIAS=y
CONFIG_SYS_EXTRA_OPTIONS="SPIFLASH"
CONFIG_BOOTDELAY=-1
CONFIG_SYS_CONSOLE_IS_IN_ENV=y
CONFIG_HUSH_PARSER=y
CONFIG_CMD_EEPROM=y
CONFIG_CMD_I2C=y
CONFIG_CMD_SF=y
CONFIG_CMD_MII=y
... | {
"pile_set_name": "Github"
} |
// Copyright (c) 2011 The LevelDB Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file. See the AUTHORS file for names of contributors.
#ifndef STORAGE_LEVELDB_DB_SNAPSHOT_H_
#define STORAGE_LEVELDB_DB_SNAPSHOT_H_
#include "db/dbformat.h"... | {
"pile_set_name": "Github"
} |
<a href="/home"><img src="/public/home.svg" alt="Application home" /><span translate="yes">Ikhaya</span></a>
<a href="/administrator" translate="yes">Ukuphatha</a>
<a href="/administrator/sessions" translate="yes">Izikhathi</a>
<a href="/administrator/session?sessionid=${session.sessionid}" translate="yes">Buka ${sessi... | {
"pile_set_name": "Github"
} |
// go run mksyscall.go -tags linux,arm64 syscall_linux.go syscall_linux_arm64.go
// Code generated by the command above; see README.md. DO NOT EDIT.
// +build linux,arm64
package unix
import (
"syscall"
"unsafe"
)
var _ syscall.Errno
// THIS FILE IS GENERATED BY THE COMMAND AT THE TOP; DO NOT EDIT
func fanotify... | {
"pile_set_name": "Github"
} |
/* Copyright 2015 The TensorFlow Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or a... | {
"pile_set_name": "Github"
} |
/*
* Copyright (C) 2017 The Android Open Source Project
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by app... | {
"pile_set_name": "Github"
} |
/**
* Copyright (c) 2015 - 2017, Nordic Semiconductor ASA
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* 1. Redistributions of source code must retain the above copyright notice,... | {
"pile_set_name": "Github"
} |
<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="refresh" content="0;URL=fn.fchdir.html">
</head>
<body>
<p>Redirecting to <a href="fn.fchdir.html">fn.fchdir.html</a>...</p>
<script>location.replace("fn.fchdir.html" + location.search + location.hash);</script>
</body>
</html> | {
"pile_set_name": "Github"
} |
////////////////////////////////////////////////////////////////////////////
//
// show_mask3 for ProcessViewServer created: Do Nov 9 15:53:54 2006
//
////////////////////////////////////////////////////////////////////////////
#include "pvapp.h"
// _begin_of_generated_area_ (do not edit -> use ui2pvc) ---------------... | {
"pile_set_name": "Github"
} |
'use strict';
require('../../modules/es6.map');
require('../../modules/es7.map.from');
var $Map = require('../../modules/_core').Map;
var $from = $Map.from;
module.exports = function from(source, mapFn, thisArg) {
return $from.call(typeof this === 'function' ? this : $Map, source, mapFn, thisArg);
};
| {
"pile_set_name": "Github"
} |
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<document type="com.apple.InterfaceBuilder3.Cocoa.XIB" version="3.0" toolsVersion="6254" systemVersion="14B25" targetRuntime="MacOSX.Cocoa" propertyAccessControl="none" promptedForUpgradeToXcode5="NO">
<dependencies>
<plugIn identifier="com.apple.Interf... | {
"pile_set_name": "Github"
} |
/**
* @example oglplus/025_multi_viewport.cpp
* @brief Shows how to draw into multiple viewport at the same time
*
* @oglplus_screenshot{025_multi_viewport}
*
* Copyright 2008-2019 Matus Chochlik. Distributed under the Boost
* Software License, Version 1.0. (See accompanying file
* LICENSE_1_0.txt or copy... | {
"pile_set_name": "Github"
} |
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" co... | {
"pile_set_name": "Github"
} |
package org.estatio.module.asset.dom;
import java.util.List;
import com.google.common.collect.Lists;
import org.jmock.Expectations;
import org.jmock.auto.Mock;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.apache.isis.core.unittestsupport.jmocking.JUnitRuleMockery2;
import org.i... | {
"pile_set_name": "Github"
} |
import * as React from 'react';
import { DropdownSelectedItem } from 'src/components/Dropdown/DropdownSelectedItem';
import { getRenderedAttribute } from 'test/specs/commonTests';
import { mountWithProviderAndGetComponent } from 'test/utils';
describe('DropdownSelectedItem', () => {
describe('active', () => {
i... | {
"pile_set_name": "Github"
} |
<?xml version="1.0" encoding="UTF-8"?>
<Project xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
xmlns:foaf="http://xmlns.com/foaf/0.1/"
xmlns:gnome="http://api.gnome.org/doap-extensions#"
xmlns="http://usefulinc.com/ns/doap#"... | {
"pile_set_name": "Github"
} |
var Q = require('q');
var fs = require('../util/fs');
var path = require('path');
var mout = require('mout');
var resolvers = require('./resolvers');
var createError = require('../util/createError');
var resolve = require('../util/resolve');
var pluginResolverFactory = require('./resolvers/pluginResolverFactory');
fu... | {
"pile_set_name": "Github"
} |
USE ndbinfo;
SELECT COUNT(*) FROM nodes;
COUNT(*)
2
DROP TABLE ndbinfo.ndb$nodes;
SELECT COUNT(*) FROM nodes;
ERROR HY000: View 'ndbinfo.nodes' references invalid table(s) or column(s) or function(s) or definer/invoker of view lack rights to use them
# restart:--upgrade=FORCE
SELECT COUNT(*) FROM nodes;
COUNT(*)
2
incl... | {
"pile_set_name": "Github"
} |
Apache Kafka
Copyright 2016 The Apache Software Foundation.
This product includes software developed at
The Apache Software Foundation (http://www.apache.org/).
This distribution has a binary dependency on jersey, which is available under the CDDL
License. The source code of jersey can be found at https://github.com/... | {
"pile_set_name": "Github"
} |
//
// MJRefreshBackGifFooter.h
// MJRefreshExample
//
// Created by MJ Lee on 15/4/24.
// Copyright (c) 2015年 小码哥. All rights reserved.
//
#import "MJRefreshBackStateFooter.h"
@interface MJRefreshBackGifFooter : MJRefreshBackStateFooter
@property (weak, nonatomic, readonly) UIImageView *gifView;
/** 设置state状态下的动... | {
"pile_set_name": "Github"
} |
// boost/timer/config.hpp -----------------------------------------------------------//
// Copyright Beman Dawes 2003, 2006, 2011
// Distributed under the Boost Software License, Version 1.0.
// See http://www.boost.org/LICENSE_1_0.txt
// See http://www.boost.org/libs/timer for documentation.
#ifndef... | {
"pile_set_name": "Github"
} |
/* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
* All rights reserved.
*
* This package is an SSL implementation written
* by Eric Young (eay@cryptsoft.com).
* The implementation was written so as to conform with Netscapes SSL.
*
* This library is free for commercial and non-commercial use as long as
... | {
"pile_set_name": "Github"
} |
2012-06-16 Stacey Sheldon <stac@solidgoldbomb.org>
* initial version
| {
"pile_set_name": "Github"
} |
var express = require('express');
var fs = require('fs');
var io = require('socket.io');
var _ = require('underscore');
var Mustache = require('mustache');
var app = express.createServer();
var staticDir = express.static;
io = io.listen(app);
var opts = {
port : 1947,
... | {
"pile_set_name": "Github"
} |
#!/usr/bin/env python
#
# Copyright 2008, Google Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list... | {
"pile_set_name": "Github"
} |
// Copyright (c) 2017-2019 The WaykiChain Core Developers
// Distributed under the MIT/X11 software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php
#include "httpserver.h"
#include "rpc/core/rpcprotocol.h" // For HTTP status codes
#include "commons/util/util.h"
#inc... | {
"pile_set_name": "Github"
} |
<!DOCTYPE HTML>
<!--
/*
* jQuery Iframe Transport Plugin Redirect Page 2.0.1
* https://github.com/blueimp/jQuery-File-Upload
*
* Copyright 2010, Sebastian Tschan
* https://blueimp.net
*
* Licensed under the MIT license:
* http://www.opensource.org/licenses/MIT
*/
-->
<html lang="en">
<head>
<meta charset="utf-... | {
"pile_set_name": "Github"
} |
'use strict';
var strong = require('./_collection-strong');
var validate = require('./_validate-collection');
var MAP = 'Map';
// 23.1 Map Objects
module.exports = require('./_collection')(MAP, function (get) {
return function Map() { return get(this, arguments.length > 0 ? arguments[0] : undefined); };
}, {
// 23... | {
"pile_set_name": "Github"
} |
/*
* Bink Audio decoder
* Copyright (c) 2007-2011 Peter Ross (pross@xvid.org)
* Copyright (c) 2009 Daniel Verkamp (daniel@drv.nu)
*
* This file is part of FFmpeg.
*
* FFmpeg is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by t... | {
"pile_set_name": "Github"
} |
import sys
import json
import csv
##
# Convert to string keeping encoding in mind...
##
def to_string(s):
try:
return str(s)
except:
#Change the encoding type if needed
return s.encode('utf-8')
##
# This function converts an item like
# {
# "item_1":"value_11",
# "item_2":"value_... | {
"pile_set_name": "Github"
} |
module.exports = function (fork) {
var types = fork.use(require("./types"));
var n = types.namedTypes;
var b = types.builders;
var isNumber = types.builtInTypes.number;
var isArray = types.builtInTypes.array;
var Path = fork.use(require("./path"));
var Scope = fork.use(require("./scope"));
... | {
"pile_set_name": "Github"
} |
<?php
/**
* @author jan huang <bboyjanhuang@gmail.com>
* @copyright 2017
*
* @see https://www.github.com/janhuang
* @see https://fastdlabs.com
*/
namespace Middleware;
use FastD\Middleware\DelegateInterface;
use FastD\Middleware\Middleware;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Messa... | {
"pile_set_name": "Github"
} |
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<title>Vue.element example</title>
<script src="https://rawgit.com/webcomponents/webcomponentsjs/v0.6.1/webcomponents.min.js"></script>
<script src="https://rawgit.com/yyx990803/vue/0.11.10/dist/vue.js"></script>
<script src="../vue-el... | {
"pile_set_name": "Github"
} |
; config options
; The island of trust is at example.com
server:
trust-anchor: "example.com. 3600 IN DS 2854 3 1 46e4ffc6e9a4793b488954bd3f0cc6af0dfb201b"
val-override-date: "20070916134226"
target-fetch-policy: "0 0 0 0 0"
qname-minimisation: "no"
fake-sha1: yes
trust-anchor-signaling: no
stub-z... | {
"pile_set_name": "Github"
} |
/**********************************************************************
* LeechCraft - modular cross-platform feature rich internet client.
* Copyright (C) 2006-2014 Georg Rudoy
*
* Distributed under the Boost Software License, Version 1.0.
* (See accompanying file LICENSE or copy at https://www.boost.org/LICENSE... | {
"pile_set_name": "Github"
} |
# ##### BEGIN GPL LICENSE BLOCK #####
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distrib... | {
"pile_set_name": "Github"
} |
好奇心原文链接:[陌陌,现在差不多是个做直播的公司吧_商业_好奇心日报-吴羚玮](https://www.qdaily.com/articles/31212.html)
WebArchive归档链接:[陌陌,现在差不多是个做直播的公司吧_商业_好奇心日报-吴羚玮](http://web.archive.org/web/20171017170541/http://www.qdaily.com:80/articles/31212.html)
 | {
"pile_set_name": "Github"
} |
{
"Initial": "AQAAAA7WcSPSEKKYmP5c",
"Version": "0.2",
"Converter": {
"ClearHeaders": [
"^X-Goog-.*Encryption-Key$",
"^X-Ms-Date$",
"^User-Agent$"
],
"RemoveRequestHeaders": [
"^Authorization$",
"^Proxy-Authorization$",
"^Connection$",
"^Content-Type$",
... | {
"pile_set_name": "Github"
} |
// Copyright (c) 2016-2019 Nuxi (https://nuxi.nl/) and contributors.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
// notice, this list of ... | {
"pile_set_name": "Github"
} |
{
"position": {
"line": 6,
"character": 44
},
"source": "expression_context/source/anon_func_expr_ctx_source6.bal",
"items": [
{
"label": "AnnotationType",
"kind": "Struct",
"detail": "Record",
"insertText": "AnnotationType",
"insertTextFormat": "Snippet"
},
{
... | {
"pile_set_name": "Github"
} |
---
title: Styles.Application Property (Word)
keywords: vbawd10.chm153945064
f1_keywords:
- vbawd10.chm153945064
ms.prod: word
api_name:
- Word.Styles.Application
ms.assetid: ae69970e-ad03-1a1f-5e14-c7d309dd9903
ms.date: 06/08/2017
---
# Styles.Application Property (Word)
Returns an **[Application](application-obje... | {
"pile_set_name": "Github"
} |
/*
* Copyright (C) 2019 The Android Open Source Project
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by app... | {
"pile_set_name": "Github"
} |
/*
* Project: VizKit
* Version: 2.3
* Date: 20090823
* File: VisualAppleScript.h
*
*/
/***************************************************************************
Copyright (c) 2004-2009 Heiko Wichmann (http://www.imagomat.de/vizkit)
This software is provided 'as-is', without any expressed or implied warran... | {
"pile_set_name": "Github"
} |
// Copyright 2008 Cyrus Najmabadi
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to... | {
"pile_set_name": "Github"
} |
id: dsq-1118342118
date: 2013-11-11T10:06:58.0000000-08:00
name: Stephen Hammond
avatar: https://disqus.com/api/users/avatars/stephenhammond.jpg
message: <p>There seem to be a lot of folks who disagree with reducing the use of "if" statements. I think this is because the "if" statement is one of the first lessons in pr... | {
"pile_set_name": "Github"
} |
# Copyright 2015 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applica... | {
"pile_set_name": "Github"
} |
<!DOCTYPE HTML>
<html>
<head>
<style>
html {
background: white;
}
div {
background: -moz-linear-gradient(left, 0 white, 100% orange);
background: linear-gradient(left, 0 white, 100% orange);
height: 100px;
width: 50%;
}
</style>
</head>
<body>
<div></div>
</body>
</html>
| {
"pile_set_name": "Github"
} |
apiVersion: apiextensions.k8s.io/v1beta1
kind: CustomResourceDefinition
metadata:
name: apicurioregistries.apicur.io
spec:
group: apicur.io
names:
kind: ApicurioRegistry
listKind: ApicurioRegistryList
plural: apicurioregistries
singular: apicurioregistry
scope: Namespaced
subresources:
sta... | {
"pile_set_name": "Github"
} |
/*
* Arizona haptics driver
*
* Copyright 2012 Wolfson Microelectronics plc
*
* Author: Mark Brown <broonie@opensource.wolfsonmicro.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License version 2 as
* published by the Free Software ... | {
"pile_set_name": "Github"
} |
#reporters
com.opensoc.metrics.reporter.graphite=true
com.opensoc.metrics.reporter.console=false
com.opensoc.metrics.reporter.jmx=false
#Graphite Addresses
com.opensoc.metrics.graphite.address=localhost
com.opensoc.metrics.graphite.port=2023
#TelemetryParserBolt
com.opensoc.metrics.TelemetryParserBolt.acks=true
com.... | {
"pile_set_name": "Github"
} |
/****************************************************************************\
Copyright (c) 2002, NVIDIA Corporation.
NVIDIA Corporation("NVIDIA") supplies this software to you in
consideration of your agreement to the following terms, and your use,
installation, modification or redistribution of this NVIDIA software... | {
"pile_set_name": "Github"
} |
batch_size: 20
buckets: 25,50,100,200
input_pipeline_dev:
class: ParallelTextInputPipeline
params:
source_files:
- ${HOME}/text-to-sql/data/imdb/with_vars/2018_02_17/query_split/1/1_encode.txt
target_files:
- ${HOME}/text-to-sql/data/imdb/with_vars/2018_02_17/query_split/1/1_decode.txt
input_pipelin... | {
"pile_set_name": "Github"
} |
// Metawidget
//
// For historical reasons, this file is licensed under the LGPL
// (http://www.gnu.org/licenses/lgpl-2.1.html).
//
// Most other files in Metawidget are licensed under both the
// LGPL/EPL and a commercial license. See http://metawidget.org
// for details.
package org.metawidget.swing.layout;
import ... | {
"pile_set_name": "Github"
} |
-----BEGIN PUBLIC KEY-----
MIIBHjANBgkqhkiG9w0BAQEFAAOCAQsAMIIBBgKB/gy7mjaWgPeFdVYDZWRCA9BN
iv3pPb0es27+FKY0hszLaOw47ExCtAWpDsH48TXAfyHBYwBLguayfk4LGIupxb+C
GMbRo3xEp0CbfY1Jby26T9vGjRC1foHDDUJG84uaRbyHqaf4i6zt4gVR+xlAEIjk
aFAAK8cOoXAT1CVqGLLljUCchL8PjaHj/yriZ/S7rdwlI3LnABxwwmLrmR/v71Wt
pmO/aNG8N+1po+QwaghTkyQ59E/ZvAuOk... | {
"pile_set_name": "Github"
} |
# Layout Configuration
The layout configuration is passed into the `options.layout` namespace. The global options for the chart layout is defined in `Chart.defaults.global.layout`.
| Name | Type | Default | Description
| -----| ---- | --------| -----------
| `padding` | `Number` or `Object` | `0` | The padding to add... | {
"pile_set_name": "Github"
} |
import 'package:flutter/material.dart';
import 'package:tik_tok_ui/home.dart';
void main() => runApp(MyApp());
class MyApp extends StatelessWidget {
// This widget is the root of your application.
@override
Widget build(BuildContext context) {
return MaterialApp(
title: 'Flutter Demo',
theme: Th... | {
"pile_set_name": "Github"
} |
---
other:
- |
A new method ``supports_power_sync`` has been added to ``PowerInterface``.
If it returns ``False``, the conductor will not try to assert power state
for the node, merely recording the returned state instead.
- |
The base agent deploy interface code now correctly handles power interfac... | {
"pile_set_name": "Github"
} |
<?xml version="1.0" encoding="utf-8"?>
<packages>
<package id="shim" version="2.0.0" targetFramework="portable-net45+win+wpa81+MonoAndroid10+xamarinios10+MonoTouch10" />
</packages> | {
"pile_set_name": "Github"
} |
#!/bin/sh
set -e
cd $(dirname $0)
. ../../../common/config.sh
. ../../../common/log.sh
log_start "$0" "chgpasswd checks that -e and -c are not provided at the same time"
save_config
# restore the files on exit
trap 'log_status "$0" "FAILURE"; restore_config' 0
change_config
echo -n "Password are encrypted and m... | {
"pile_set_name": "Github"
} |
import torch.nn as nn
from torch.autograd import Function
from torch.autograd.function import once_differentiable
from torch.nn.modules.utils import _pair
from . import roi_align_cuda
class RoIAlignFunction(Function):
@staticmethod
def forward(ctx, features, rois, out_size, spatial_scale, sample_num=0):
... | {
"pile_set_name": "Github"
} |
#! /usr/bin/env python
from __future__ import print_function
import sys
import io
import codecs
import argparse
from subprocess import Popen, PIPE
if __name__ == '__main__':
parser = argparse.ArgumentParser(description='Convert phone representation to words')
parser.add_argument('--p2g-cmd', default=None)
args... | {
"pile_set_name": "Github"
} |
#include "nonexistent.h"
int *f() { return fp; }
| {
"pile_set_name": "Github"
} |
<div class="post-wrap" >
<div class="m-post">
<?php
$format = get_post_format();
if( false === $format ) { $format = 'standard'; }
?>
<a class="typeicon <?php echo $format; ?>" href="<?php the_permalink(); ?>"></a>
<div class="content">
<h2 class="title"><a href="<?php the_permalink(); ?>" ti... | {
"pile_set_name": "Github"
} |
; SPIR-V\n"
; Version: 1.0
; Generator: Khronos Glslang Reference Front End; 1
; Updated bound to reflect hand added variables
; Bound: 32
; Schema: 0
OpCapability Shader
%1 = OpExtInstImport "GLSL.std.450"
OpMemoryModel Logical GLSL450
OpEntryPoint Fragment %4 "ma... | {
"pile_set_name": "Github"
} |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.